pub struct Keypair { /* private fields */ }Expand description
Private and public keypair used for nodes and cells.
Implementations
Sourceimpl Keypair
impl Keypair
pub fn from_libp2p(keypair: libp2p_Keypair) -> Keypair
pub fn generate_ed25519() -> Keypair
pub fn public(&self) -> PublicKey
pub fn algorithm(&self) -> Algorithm
pub fn to_libp2p(&self) -> &libp2p_Keypair
Sourcepub fn sign(&self, msg: &[u8]) -> Result<Vec<u8>, Error>
pub fn sign(&self, msg: &[u8]) -> Result<Vec<u8>, Error>
Sign given message with the keypair.
The verify method on the public key can be used to validate signature.
Sourcepub fn encode_base58_string(&self) -> String
pub fn encode_base58_string(&self) -> String
Encode the keypair into a base58 representation